/*****************************************************************************
* File Name: main.c
*
* Description:
* Main.c for project D_SysTick for application note AN54460. Initializes
* Cortex-M3 SysTick registers, and toggles an LED on each SysTick interrupt.
*
* Related Document:
* Application note AN54460, PSoC 3/5LP Interrupts
*
* Hardware Dependency:
* Designed for PSoC 5LP. Designed for CY8CKIT-001 but can be easily
* adapted to work with any kit.
*
* Code Tested With:
* 1. PSoC Creator 3.0 SP1
* 2. PSoC Creator 4.1 SP1
*
* Copyright (2013), Cypress Semiconductor Corporation.
*/

#include <project.h>

#define SYSTICK_INTERRUPT_VECTOR_NUMBER  15u      // Cortex-M3 exception

/* clock and interrupt rates, in Hz */
#define CLOCK_FREQ     BCLK__BUS_CLK__HZ
#define INTERRUPT_FREQ 2u


/*****************************************************************************
* Function Name: SysTick_ISR
******************************************************************************
* Summary: Toggle LED on interrupts of SysTick. No need to clear interrupt flag.
* Parameters: none; it's an ISR function
* Return: none; it's an ISR function
*****************************************************************************/
CY_ISR(SysTick_ISR) {
    LED_Write(~LED_Read()); 
}

int main() {
    /* Point the Systick vector to the ISR in this file */
    CyIntSetSysVector(SYSTICK_INTERRUPT_VECTOR_NUMBER, SysTick_ISR);

    /* Set the number of ticks between interrupts.
       Ignore the function success/fail return value.
	   Defined in auto-generated core_cm3.h   */
    (void)SysTick_Config(CLOCK_FREQ / INTERRUPT_FREQ); 

    CyGlobalIntEnable;  /* Enable global interrupts. */

    for(;;)
    {
        /* Do nothing in the main loop; code to do
		something is in the ISR */
    }
}

/* [] END OF FILE */
